@@ -33,6 +33,10 @@ class DeploymentSchema(BaseSchema):
     ports = ma.fields.Str(dump_to="ports", load_from="ports")
     auth_username = ma.fields.Str(dump_to="oauthKey", load_from="oauthKey")
     auth_password = ma.fields.Str(dump_to="oauthSecret", load_from="oauthSecret")
-    cluster_id = ma.fields.Str(dump_to="cluster", load_from="clusterId")
+    cluster_id = ma.fields.Str(dump_to="clusterId", load_from="clusterId")
     tags = ma.fields.List(ma.fields.Str(), load_only=True)
     command = ma.fields.Str()
+
+
+class DeploymentCreateSchema(DeploymentSchema):
+    cluster_id = ma.fields.Str(dump_to="cluster", load_from="clusterId")
